import { useState, useEffect } from "react";
import { motion, AnimatePresence } from "framer-motion";
import { Menu, X, Loader2 } from "lucide-react";
import { Button } from "@/components/ui/button";

export default function Navigation() {
  const [isOpen, setIsOpen] = useState(false);
  const [scrollY, setScrollY] = useState(0);

  useEffect(() => {
    const handleScroll = () => setScrollY(window.scrollY);
    window.addEventListener('scroll', handleScroll);
    return () => window.removeEventListener('scroll', handleScroll);
  }, []);

  const scrollToSection = (sectionId: string) => {
    const element = document.getElementById(sectionId);
    if (element) {
      element.scrollIntoView({ behavior: "smooth" });
    }
    setIsOpen(false);
  };

  return (
    <nav className="fixed top-0 left-0 right-0 z-50 backdrop-blur-lg bg-gradient-to-r from-black/20 via-purple-900/10 to-black/20">
      <div className="max-w-7xl mx-auto px-6 lg:px-8">
        <div className="flex items-center justify-between h-16">
          <div className="flex items-center space-x-2 relative">
            <div className="absolute -inset-2 bg-gradient-to-r from-gray-500/10 via-purple-500/20 to-purple-600/15 rounded-lg blur-lg opacity-60"></div>
            <div className="relative flex items-center space-x-2">
              <motion.div
                className="w-10 h-10 flex items-center justify-center"
                whileHover={{ scale: 1.05 }}
                transition={{ type: "spring", stiffness: 400, damping: 17 }}
              >
                <img 
                  src="/images/oktogon-logo.svg" 
                  alt="OktoPeople Logo" 
                  className="w-10 h-10 filter brightness-0 invert"
                />
              </motion.div>
              <div className="text-white font-semibold text-xl tracking-tight">
                OktoPeople
              </div>
            </div>
          </div>

          <div className="hidden md:flex items-center space-x-8">
            <button
              onClick={() => scrollToSection("hero")}
              className="text-white/80 hover:text-white transition-colors duration-200 text-sm font-medium"
            >
              Home
            </button>
            <button
              onClick={() => scrollToSection("enterprise")}
              className="text-white/80 hover:text-white transition-colors duration-200 text-sm font-medium"
            >
              Principles
            </button>
            <button
              onClick={() => scrollToSection("products")}
              className="text-white/80 hover:text-white transition-colors duration-200 text-sm font-medium"
            >
              Products
            </button>
            <button
              onClick={() => scrollToSection("services")}
              className="text-white/80 hover:text-white transition-colors duration-200 text-sm font-medium"
            >
              Services
            </button>
            <button
              onClick={() => scrollToSection("webinar")}
              className="text-white/80 hover:text-white transition-colors duration-200 text-sm font-medium"
            >
              Webinar
            </button>
            <motion.button
              className="relative px-6 py-2 rounded-xl text-white font-medium overflow-hidden group bg-transparent border-2"
              style={{
                borderImage: `conic-gradient(
                  from var(--border-angle, 0deg),
                  transparent 0deg,
                  transparent 270deg,
                  rgba(139, 92, 246, 0.8) 300deg,
                  rgba(16, 185, 129, 0.8) 330deg,
                  rgba(59, 130, 246, 0.8) 360deg,
                  transparent 390deg,
                  transparent 720deg
                ) 1`,
                '--border-angle': '0deg'
              } as any}
              onClick={() => window.location.href = "/investor-form"}
              whileHover={{ scale: 1.05 }}
              whileTap={{ scale: 0.95 }}
              animate={{
                '--border-angle': ['0deg', '360deg']
              } as any}
              transition={{
                duration: 3,
                repeat: Infinity,
                ease: "linear"
              }}
            >
              <span className="relative z-10">
                Join Investor Day
              </span>
            </motion.button>
          </div>

          <button 
            className="md:hidden text-white"
            onClick={() => setIsOpen(!isOpen)}
          >
            {isOpen ? <X className="w-6 h-6" /> : <Menu className="w-6 h-6" />}
          </button>
        </div>
      </div>

      <AnimatePresence>
        {isOpen && (
          <motion.div
            initial={{ opacity: 0, height: 0 }}
            animate={{ opacity: 1, height: "auto" }}
            exit={{ opacity: 0, height: 0 }}
            className="md:hidden bg-black/30 backdrop-blur-lg border-t border-white/10"
          >
            <div className="px-6 py-6 space-y-6">
              <button
                onClick={() => scrollToSection("hero")}
                className="block text-white/80 hover:text-white transition-colors duration-200 text-lg font-medium"
              >
                Home
              </button>
              <button
                onClick={() => scrollToSection("enterprise")}
                className="block text-white/80 hover:text-white transition-colors duration-200 text-lg font-medium"
              >
                Principles
              </button>
              <button
                onClick={() => scrollToSection("products")}
                className="block text-white/80 hover:text-white transition-colors duration-200 text-lg font-medium"
              >
                Products
              </button>
              <button
                onClick={() => scrollToSection("services")}
                className="block text-white/80 hover:text-white transition-colors duration-200 text-lg font-medium"
              >
                Services
              </button>
              <button
                onClick={() => scrollToSection("webinar")}
                className="block text-white/80 hover:text-white transition-colors duration-200 text-lg font-medium"
              >
                Webinar
              </button>
              <motion.button
                className="relative px-6 py-2 rounded-xl text-white font-medium overflow-hidden group bg-transparent border-2"
                style={{
                  borderImage: `conic-gradient(
                    from var(--border-angle, 0deg),
                    transparent 0deg,
                    transparent 270deg,
                    rgba(139, 92, 246, 0.8) 300deg,
                    rgba(16, 185, 129, 0.8) 330deg,
                    rgba(59, 130, 246, 0.8) 360deg,
                    transparent 390deg,
                    transparent 720deg
                  ) 1`,
                  '--border-angle': '0deg'
                } as any}
                onClick={() => window.location.href = "/investor-form"}
                whileHover={{ scale: 1.05 }}
                whileTap={{ scale: 0.95 }}
                animate={{
                  '--border-angle': ['0deg', '360deg']
                } as any}
                transition={{
                  duration: 3,
                  repeat: Infinity,
                  ease: "linear"
                }}
              >
                <span className="relative z-10">
                  Join Investor Day
                </span>
              </motion.button>
            </div>
          </motion.div>
        )}
      </AnimatePresence>
    </nav>
  );
}